@@ -1,4 +1,4 @@
-# Copyright 2017-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2017-2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You may
 # not use this file except in compliance with the License. A copy of the License is located at
@@ -21,8 +21,9 @@ class Evaluator:
     __rdk_rule = None
     __expected_resource_types = None
 
-    def __init__(self, config_rule, expected_resource_types=None):
+    def __init__(self, config_rule, expected_resource_types=None, is_applicable_status=False):
         self.__rdk_rule = config_rule
+        self.is_applicable = is_applicable_status
         if expected_resource_types is None:
             self.__expected_resource_types = []
         else:
@@ -32,7 +33,7 @@ class Evaluator:
 
         check_defined(event, 'event')
 
-        client_factory = ClientFactory(self.__rdk_rule.get_execution_role_arn(event))
+        client_factory = ClientFactory(role_arn=self.__rdk_rule.get_execution_role_arn(event), region=self.__rdk_rule.get_assume_role_region(event), assume_role_mode=self.__rdk_rule.get_assume_role_mode(event))
         invoking_event = init_event(event, client_factory)
 
         rule_parameters = {}
@@ -52,7 +53,7 @@ class Evaluator:
                 if not self.__expected_resource_types:
                     raise Exception("Change triggered rules must provide expected resource types")
                 configuration_item = get_configuration_item(invoking_event)
-                if is_applicable_status(configuration_item, event) and is_applicable_resource_type(configuration_item, self.__expected_resource_types):
+                if is_applicable_status(configuration_item, event, is_applicable=self.is_applicable) and is_applicable_resource_type(configuration_item, self.__expected_resource_types):
                     compliance_result = self.__rdk_rule.evaluate_change(event, client_factory, configuration_item, valid_rule_parameters)
                 else:
                     compliance_result = [Evaluation(ComplianceType.NOT_APPLICABLE)]
